@@ -639,6 +639,11 @@ class Object(Client):
         }.items() if value}
         return await self.client.request('DELETE', self.uri, **headers)  # type: ignore # <https://github.com/python/mypy/issues/10008>
 
+    async def restore(self, reload: bool = True) -> Response:
+        """Restore an object from the recyclebin."""
+        uri = self.client.get_relation(self.hal, 'udm:restore')['href']
+        return await self._request('POST', uri, {}, {}, reload=reload)
+
     async def move(self, position: str, reload: bool = True) -> None:
         self.position = position
         await self.save(reload=reload)
